package com.jiuqi.db;

package .tmp;

import com.jiuqi.db.DBPreparedStatement;
import com.jiuqi.db.DBStatement;
import com.jiuqi.db.DBTrace;
import com.jiuqi.db.IConnection;
import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.Savepoint;
import java.sql.Statement;
import java.util.Map;

public class DBConnection implements Connection {
  private Connection conn;
  
  private boolean isTransManaged = false;
  
  public DBConnection(IConnection aConn) {
    this.isTransManaged = false;
    this.conn = aConn.getConnection();
    DBTrace.createConnection(this);
  }
  
  public DBConnection(Connection aConn) {
    this.isTransManaged = false;
    this.conn = aConn;
    DBTrace.createConnection(this);
  }
  
  public DBConnection(IConnection aConn, boolean transManaged, boolean autoCommit) throws SQLException {
    this.isTransManaged = transManaged;
    this.conn = aConn.getConnection();
    this.conn.setAutoCommit(autoCommit);
    DBTrace.createConnection(this);
  }
  
  public DBConnection(Connection aConn, boolean transManaged, boolean autoCommit) throws SQLException {
    this.isTransManaged = transManaged;
    this.conn = aConn;
    this.conn.setAutoCommit(autoCommit);
    DBTrace.createConnection(this);
  }
  
  public Statement createStatement() throws SQLException {
    Statement stmt = this.conn.createStatement();
    return (Statement)new DBStatement(stmt, this);
  }
  
  public PreparedStatement prepareStatement(String string) throws SQLException {
    PreparedStatement stmt = this.conn.prepareStatement(string);
    return (PreparedStatement)new DBPreparedStatement(stmt, this);
  }
  
  public CallableStatement prepareCall(String string) throws SQLException {
    return this.conn.prepareCall(string);
  }
  
  public String nativeSQL(String string) throws SQLException {
    return this.conn.nativeSQL(string);
  }
  
  public void setAutoCommit(boolean boolean0) throws SQLException {
    if (this.isTransManaged)
      return; 
    this.conn.setAutoCommit(boolean0);
  }
  
  public boolean getAutoCommit() throws SQLException {
    return this.conn.getAutoCommit();
  }
  
  public void commit() throws SQLException {
    if (this.isTransManaged)
      return; 
    this.conn.commit();
  }
  
  public void rollback() throws SQLException {
    if (this.isTransManaged)
      return; 
    this.conn.rollback();
  }
  
  public void close() throws SQLException {
    DBTrace.closeConnection(this);
    if (this.isTransManaged)
      return; 
    this.conn.close();
  }
  
  public boolean isClosed() throws SQLException {
    return this.conn.isClosed();
  }
  
  public DatabaseMetaData getMetaData() throws SQLException {
    return this.conn.getMetaData();
  }
  
  public void setReadOnly(boolean boolean0) throws SQLException {
    this.conn.setReadOnly(boolean0);
  }
  
  public boolean isReadOnly() throws SQLException {
    return this.conn.isReadOnly();
  }
  
  public void setCatalog(String string) throws SQLException {
    this.conn.setCatalog(string);
  }
  
  public String getCatalog() throws SQLException {
    return this.conn.getCatalog();
  }
  
  public void setTransactionIsolation(int int0) throws SQLException {
    this.conn.setTransactionIsolation(int0);
  }
  
  public int getTransactionIsolation() throws SQLException {
    return this.conn.getTransactionIsolation();
  }
  
  public SQLWarning getWarnings() throws SQLException {
    return this.conn.getWarnings();
  }
  
  public void clearWarnings() throws SQLException {
    this.conn.clearWarnings();
  }
  
  public Statement createStatement(int int0, int int1) throws SQLException {
    Statement stmt = this.conn.createStatement(int0, int1);
    return (Statement)new DBStatement(stmt, this.conn);
  }
  
  public PreparedStatement prepareStatement(String string, int int1, int int2) throws SQLException {
    PreparedStatement stmt = this.conn.prepareStatement(string, int1, int2);
    return (PreparedStatement)new DBPreparedStatement(stmt, this);
  }
  
  public CallableStatement prepareCall(String string, int int1, int int2) throws SQLException {
    return this.conn.prepareCall(string, int1, int2);
  }
  
  public Map getTypeMap() throws SQLException {
    return this.conn.getTypeMap();
  }
  
  public void setTypeMap(Map<String, Class<?>> map) throws SQLException {
    this.conn.setTypeMap(map);
  }
  
  public void setHoldability(int holdability) throws SQLException {
    this.conn.setHoldability(holdability);
  }
  
  public int getHoldability() throws SQLException {
    return this.conn.getHoldability();
  }
  
  public Savepoint setSavepoint() throws SQLException {
    return this.conn.setSavepoint();
  }
  
  public Savepoint setSavepoint(String name) throws SQLException {
    return this.conn.setSavepoint(name);
  }
  
  public void rollback(Savepoint savepoint) throws SQLException {
    this.conn.rollback(savepoint);
  }
  
  public void releaseSavepoint(Savepoint savepoint) throws SQLException {
    this.conn.releaseSavepoint(savepoint);
  }
  
  public Statement createStatement(int resultSetType, int resultSetConcurrency, int resultSetHoldability) throws SQLException {
    Statement stmt = this.conn.createStatement(resultSetType, resultSetConcurrency);
    return (Statement)new DBStatement(stmt, this);
  }
  
  public PreparedStatement prepareStatement(String sql, int resultSetType, int resultSetConcurrency, int resultSetHoldability) throws SQLException {
    PreparedStatement stmt = this.conn.prepareStatement(sql, resultSetType, resultSetConcurrency, resultSetHoldability);
    return (PreparedStatement)new DBPreparedStatement(stmt, this);
  }
  
  public CallableStatement prepareCall(String sql, int resultSetType, int resultSetConcurrency, int resultSetHoldability) throws SQLException {
    return this.conn.prepareCall(sql, resultSetType, resultSetConcurrency, resultSetHoldability);
  }
  
  public PreparedStatement prepareStatement(String sql, int autoGeneratedKeys) throws SQLException {
    PreparedStatement stmt = this.conn.prepareStatement(sql, autoGeneratedKeys);
    return (PreparedStatement)new DBPreparedStatement(stmt, this);
  }
  
  public PreparedStatement prepareStatement(String sql, int[] columnIndexes) throws SQLException {
    PreparedStatement stmt = this.conn.prepareStatement(sql, columnIndexes);
    return (PreparedStatement)new DBPreparedStatement(stmt, this);
  }
  
  public PreparedStatement prepareStatement(String sql, String[] columnNames) throws SQLException {
    PreparedStatement stmt = this.conn.prepareStatement(sql, columnNames);
    return (PreparedStatement)new DBPreparedStatement(stmt, this);
  }
}
